@@ -1,5 +1,6 @@
 from django.db.models import QuerySet
 from rest_framework.pagination import CursorPagination as DefaultCursorPagination
+from rest_framework.pagination import LimitOffsetPagination as DefaultLimitOffsetPagination
 from rest_framework.pagination import BasePagination
 from rest_framework.request import Request
 from rest_framework.response import Response
@@ -21,3 +22,8 @@ class CursorPagination(DefaultCursorPagination):
         new_ordering = [*ordering]
         new_ordering[0] = new_ordering[0].split("__")[0]
         return super()._get_position_from_instance(instance, new_ordering)
+
+
+class LimitOffsetPagination(DefaultLimitOffsetPagination):
+
+    default_limit = 25
